from enum import Enum

class JobOrderStatus(str, Enum):
    PAYMENT_VALIDATED = 'PAYMENT_VALIDATED'
    SHIPPING_LABEL_SENT_TO_SELLER = 'SHIPPING_LABEL_SENT_TO_SELLER'
    ORDER_SHIPPED = 'ORDER_SHIPPED'
    DELIVERED_TO_POST_OFFICE_OR_PICKUP_POINT = 'DELIVERED_TO_POST_OFFICE_OR_PICKUP_POINT'
    ORDER_RECEIVED = 'ORDER_RECEIVED'
    ORDER_FINALIZED = 'ORDER_FINALIZED'
    RETURN_INITIATED = 'RETURN_INITIATED'
    REFUND_DONE = 'REFUND_DONE'
    UNKNOWN = 'UNKNOWN'
